from setuptools import setup
setup(
  name='lp_push_notifications',
  packages=['lp_push_notifications'],
  package_data={'lp_push_notifications': ['migrations/*']},
  version='0.1.6',
  description='REST Framework for Push Notifications',
  author='Jim Simon',
  author_email='hello@launchpeer.com',
  url='https://github.com/Launchpeer/django-rest-push-notifications',
  download_url='https://github.com/Launchpeer/django-rest-push-notifications/archive/master.tar.gz',
  keywords=[],
  classifiers=[],
)
